package com.owrawww.domain.mapper;

import com.owrawww.domain.Bbs;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

@Mapper
public interface BbsMapper {

    List<Bbs> selectList(Map<String, Object> params);

    int selectCount(Map<String, Object> params);

    Bbs selectById(Map<String, Object> params);

    Bbs selectPrev(Map<String, Object> params);

    Bbs selectNext(Map<String, Object> params);

    int incrementViewCnt(Long id);

    List<Bbs> selectPreview(Map<String, Object> params);
}